package com.qf.controller;

import com.alipay.api.AlipayApiException;
import com.alipay.api.internal.util.AlipaySignature;
import com.qf.entity.Elefee;
import com.qf.entity.Waterfee;
import com.qf.result.ResponseResult;
import com.qf.service.ElefeeService;
import com.qf.service.WaterfeeService;
import com.qf.utils.MailUtil;
import com.qf.utils.PayUtil;
import com.qf.utils.Utils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Map;

@RestController
@RequestMapping("/waterfee")
@Slf4j
public class WaterfeeController {

    @Autowired
    WaterfeeService waterfeeService;

    @Autowired
    ElefeeService elefeeService;

    @Autowired
    PayUtil payUtil;

    @Autowired
    MailUtil mailUtil;

    @PostMapping("/pay")
    public ResponseResult pay(@RequestBody Waterfee waterfee, HttpServletRequest request, HttpServletResponse response){
        Double waterFee = waterfee.getWaterFee();
        try {
            String alipay = payUtil.alipay(request, response, waterFee,waterfee.getId());

            return ResponseResult.okResult(alipay);
        }catch (Exception e){
            return ResponseResult.errorResult(201,"支付失败");
        }
//        return ResultBean.FAIL();
    }

    @PostMapping("/notify")
    public void notifyUrl(HttpServletRequest request) throws AlipayApiException {

        //先验签,
        Map<String, String> paramsMap = Utils.convertRequestParamsToMap(request); //将异步通知中收到的所有参数都存放到 map 中

        //
        log.info(paramsMap+"====================");

        boolean  signVerified = AlipaySignature.rsaCheckV1(paramsMap, payUtil.getAPP_PRIVATE_KEY(), "utf-8", "RSA2");  //调用SDK验证签名
        //验签成功 再根据支付修改订单状态
        if (signVerified){
            // TODO 验签成功后，按照支付结果异步通知中的描述，对支付结果中的业务内容进行二次校验，校验成功后在response中返回success并继续商家自身业务处理，校验失败返回failure
            //购买成功,修改数据库
//            UpdateWrapper<User> wrapper = new UpdateWrapper<>();
//            wrapper.set("account",)


        } else {
            // TODO 验签失败则记录异常日志，并在response中返回failure.
        }
    }

    @GetMapping("/findAll")
    public ResponseResult findAll(String ownerName){
        return waterfeeService.findAll(ownerName);
    }

    @DeleteMapping("/delete/{id}")
    public ResponseResult delete(@PathVariable Integer id){
        return waterfeeService.delete(id);
    }

    @PostMapping("/add")
    public ResponseResult add(@RequestBody Waterfee waterfee){
        return waterfeeService.add(waterfee);
    }

    @GetMapping("/findAllHouse")
    public ResponseResult findAllHouse(){
        return elefeeService.findAllHouse();
    }

    @GetMapping("/findOwnerByHouseId")
    public ResponseResult findOwnerByHouseId(String house){
        return elefeeService.findOwnerByHouseId(house);
    }

}
